@@ -21,7 +21,7 @@
 
 
 from functools import wraps
-from socket import getfqdn
+from socket import getfqdn, gethostname
 
 from slimta.edge.smtp import SmtpValidators
 from slimta.smtp.auth import Auth, CredentialsInvalidError
@@ -47,7 +47,8 @@ class RuleHelpers(object):
         rules = options.get('rules', {})
         self.banner = rules.get('banner')
         if self.banner:
-            self.banner = self.banner.format(fqdn=getfqdn())
+            self.banner = self.banner.format(fqdn=getfqdn(),
+                                             hostname=gethostname())
         self.dnsbl = rules.get('dnsbl')
         self.only_senders = rules.get('only_senders')
         self.only_rcpts = rules.get('only_recipients')
@@ -88,7 +89,7 @@ def build_smtpedge_validators(options):
         def handle_rcpt(self, reply, rcpt):
             if not rules.is_recipient_ok(rcpt):
                 reply.code = '550'
-                reply.message = '5.7.1 Recipient <{0} Not allowed'.format(rcpt)
+                reply.message = '5.7.1 Recipient <{0}> Not allowed'.format(rcpt)
     return CustomValidators
 
 
@@ -116,7 +117,8 @@ def add_queue_policies(queue, policy_options):
         if policy.type == 'add_date_header':
             queue.add_policy(AddDateHeader())
         elif policy.type == 'add_messageid_header':
-            queue.add_policy(AddMessageIdHeader())
+            hostname = policy.get('hostname')
+            queue.add_policy(AddMessageIdHeader(hostname))
         elif policy.type == 'add_received_header':
             queue.add_policy(AddReceivedHeader())
         elif policy.type == 'recipient_split':
