@@ -116,12 +116,14 @@ class SlimtaState(object):
         new_relay = None
         if options.type == 'mx':
             from slimta.relay.smtp.mx import MxSmtpRelay
-            new_relay = MxSmtpRelay()
+            ehlo_as = options.get('ehlo_as')
+            new_relay = MxSmtpRelay(ehlo_as=ehlo_as)
         elif options.type == 'static':
             from slimta.relay.smtp.static import StaticSmtpRelay
             host = options.host
             port = options.get('port', 25)
-            new_relay = StaticSmtpRelay(host, port)
+            ehlo_as = options.get('ehlo_as')
+            new_relay = StaticSmtpRelay(host, port, ehlo_as=ehlo_as)
         elif options.type == 'maildrop':
             from slimta.maildroprelay import MaildropRelay
             executable = options.get('executable')
@@ -201,9 +203,7 @@ class SlimtaState(object):
             from .helpers import build_smtpedge_validators, build_smtpedge_auth
             ip = options.listener.get('interface', '127.0.0.1')
             port = int(options.listener.get('port', 25))
-            queue_name = options.get('queue')
-            if not queue_name:
-                raise ConfigError('edge sections must be given a queue name')
+            queue_name = options.queue
             queue = self._start_queue(queue_name)
             kwargs = {}
             if options.get('tls'):
@@ -214,6 +214,7 @@ class SlimtaState(object):
             kwargs['command_timeout'] = 20.0
             kwargs['data_timeout'] = 30.0
             kwargs['max_size'] = 10485760
+            kwargs['hostname'] = options.get('hostname')
             new_edge = SmtpEdge((ip, port), queue, **kwargs)
             new_edge.start()
         else:
